#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tuple
version:              0.3.0.2
visibility:           public
id:                   tuple-0.3.0.2-GCo3UFWSv0sCRNzsFPJTTv
key:                  tuple-0.3.0.2-GCo3UFWSv0sCRNzsFPJTTv
license:              BSD-3-Clause
copyright:            2014 Lennart Augustsson
maintainer:           Lennart Augustsson
author:               Lennart Augustsson
stability:            stable
synopsis:             Various functions on tuples
description:
    Various useful functions on tuples, overloaded on tuple size.

category:             Data
abi:                  94afc9469dc091ee8a333316b60736c9
exposed:              True
exposed-modules:
    Data.Tuple.All Data.Tuple.Curry Data.Tuple.Select
    Data.Tuple.Sequence Data.Tuple.Update

import-dirs:          /usr/lib/ghc-9.6.6/site-local/tuple-0.3.0.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/tuple-0.3.0.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/tuple-0.3.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tuple
hs-libraries:         HStuple-0.3.0.2-GCo3UFWSv0sCRNzsFPJTTv
depends:              OneTuple-0.4.3-LHDdl4VWBDgLOgfmdTjsbm base-4.18.2.1
haddock-interfaces:   /usr/share/doc/haskell-tuple/html/tuple.haddock
haddock-html:         /usr/share/doc/haskell-tuple/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

